# <i>Spatial Uncertainty Research Framework</i>

<img src="https://raw.githubusercontent.com/NHERI-SimCenter/SURF/master/docs/images/surf.png" alt="SURF" height="250"/>

## What is <i>SURF</i>?

<i>SURF</i> is a Python package for performing spatial uncertainty analysis uisng random fields and machine leaning.


## Documentation

[Online documentation](https://nheri-simcenter.github.io/SURF)

More details in paper: <a href="https://arxiv.org/abs/1910.06391">here</a>.

## How to cite

Charles Wang. (2019, September 28). NHERI-SimCenter/SURF: v0.2.0 (Version v0.2.0). Zenodo. http://doi.org/10.5281/zenodo.3463676

## License

<i>SURF</i> is distributed under the BSD 3-Clause license.

## Acknowledgement

This material is based upon work supported by the <img src="https://raw.githubusercontent.com/NHERI-SimCenter/SURF/master/docs/images/nsf.png"  width="20px"  alt="NSF"/> `National Science Foundation` under Grant No. 1612843. Any opinions, findings, and conclusions or recommendations expressed in this material are those of the authors and do not necessarily reflect the views of the National Science Foundation.
